@@ -139,13 +139,13 @@ def test_get_job_by_id(single_job_request):
         status=single_job_request["jobStatus"]["name"],
         date=single_job_request["jobStatus"]["date"]
     )
-    assert job.other['userId'] == single_job_request["userId"]
+    assert job.other['user_id'] == single_job_request["userId"]
 
 
 def test_get_user_jobs(user_jobs):
     gwc = GWCloud(token='my_token')
 
-    jobs = gwc._get_user_jobs()
+    jobs = gwc.get_user_jobs()
 
     assert jobs[0].job_id == user_jobs[0]["id"]
     assert jobs[0].name == user_jobs[0]["name"]
@@ -154,7 +154,7 @@ def test_get_user_jobs(user_jobs):
         status=user_jobs[0]["jobStatus"]["name"],
         date=user_jobs[0]["jobStatus"]["date"]
     )
-    assert jobs[0].other['userId'] == user_jobs[0]["userId"]
+    assert jobs[0].other['user_id'] == user_jobs[0]["userId"]
 
     assert jobs[1].job_id == user_jobs[1]["id"]
     assert jobs[1].name == user_jobs[1]["name"]
@@ -163,7 +163,7 @@ def test_get_user_jobs(user_jobs):
         status=user_jobs[1]["jobStatus"]["name"],
         date=user_jobs[1]["jobStatus"]["date"]
     )
-    assert jobs[1].other['userId'] == user_jobs[1]["userId"]
+    assert jobs[1].other['user_id'] == user_jobs[1]["userId"]
 
     assert jobs[2].job_id == user_jobs[2]["id"]
     assert jobs[2].name == user_jobs[2]["name"]
@@ -172,7 +172,7 @@ def test_get_user_jobs(user_jobs):
         status=user_jobs[2]["jobStatus"]["name"],
         date=user_jobs[2]["jobStatus"]["date"]
     )
-    assert jobs[2].other['userId'] == user_jobs[2]["userId"]
+    assert jobs[2].other['user_id'] == user_jobs[2]["userId"]
 
 
 def test_gwcloud_files_by_job_id(job_file_request):
